/* 
 * $Id: HEXTErock.h,v 3.4 1997/05/16 22:18:12 pblanco Exp pblanco $
 *
 * Modification history:
 * $Log: HEXTErock.h,v $
 * Revision 3.4  1997/05/16  22:18:12  pblanco
 * changed DEFAULT_UTDATE
 *
 * Revision 3.3  1997/05/16  22:10:31  pblanco
 * Updated constants for RXTE Cycle 3
 *
 * Revision 3.2  1996/11/20 19:30:58  pblanco
 * removed HEXTEROCK_15 and HEXTEROCK_30 macros
 *
 * Revision 3.1  1996/10/18  02:37:52  pblanco
 * For HEXTErock 3.1
 *
 * Revision 3.0  1996/09/26 20:29:13  pblanco
 * HEXTErock.c set to version 3.0
 *
 * Revision 1.10  1996/09/03 20:51:59  pblanco
 * Changed default date to DEFAULT_UTDATE
 *
 * Revision 1.9  1996/07/11  05:36:19  pblanco
 * Added TOL macro
 *
 * Revision 1.8  1996/07/10 20:50:24  pblanco
 * Added MIN2 and MAX2 macros.
 *
 * Revision 1.7  1996/06/06  23:14:27  pblanco
 * Changed XTEROLLMAX to 90.0
 */ 

/* RXTE and HEXTE default angle values, in degrees: */
#define DEFAULT_UTDATE 19970521.5	    /* default observation date */
#define XTEROLLMAX 90.0			    /* abs max roll offset (of X-Z plane from solar vector) */
#define XTESUNLIMIT 30.0		    /* XTE sun-angle pointing constraint */
#define XTEANTISUN 1.0 			    /* anti-sun angle at which roll angle cannot be predicted */

/* Constant macros: */
#ifndef PI
#define PI 3.1415926545			    /* as opposed to PI which may be in <math.h> */
#endif
#define HEXTEROCK_TOL 1.0E-5

/* Function macros: arguments must not have unary operators! */ 
#define RAD ( PI / 180.0 )		    /* radians from degrees conversion */
#define DEG ( 180.0 / PI )		    /* degrees from radians conversion */
#define MAX2(A, B) (((A) > (B))? (A): (B))  /* max. of two numbers */
#define MIN2(A, B) (((A) < (B))? (A): (B))  /* min. of two numbers */

/* Structure definitions for hexterock.c: */

/* ATTITUDE: Attitude matrix (3 rows x 3 columns). The columns 0, 1, 2 contain 
 * the inertial coordinates of the spacecraft X,Y,Z axes respectively.
 */ 
typedef struct {
  double matrix[3][3];
} ATTITUDE;				    /* attitude [3 rows] x [3 col]  */

/* VECTOR: Cartesian vector in either inertial coords (Cartesian RA and Dec), 
 * or spacecraft coords (X,Y,Z), and usually normalized to unit magnitude.
 */ 
typedef struct {
  double xyz[3];
} VECTOR;				    /* {x, y, z} */

/* RADEC: Celestial Right Ascension and Delcination coordinates. In hexterock.c
 * and associated functions, these are usually expressed in equinox J2000.0 
 * degrees.
 */ 
typedef struct {
  double ra;				    /* valid range 0.0-360.0 */
  double dec;				    /* valid range -90.0 to +90.0 */
} RADEC;				    /* {ra, dec} */

/* QUATERNION: Spacecraft attitude quaternions, as defined in Wertz */
typedef struct {
  double q[4];
} QUATERNION;				    /* {q1, q2, q3, q4} */

/* end of HEXTErock.h */
